@@ -21,7 +21,15 @@ sub BUILD ( $self, $args ) {
 
 # this method can be overrided in the child class
 sub run ( $self, $req ) {
-    $req->(404)->finish;
+
+    if ( $req->{path_tail} && $req->{path_tail}->is_file ) {
+
+        # try to return static content
+        $self->return_static($req);
+    }
+    else {
+        $req->(404)->finish;
+    }
 
     return;
 }
@@ -125,7 +133,7 @@ around BUILD => sub ( $orig, $self, $args ) {
 
 around run => sub ( $orig, $self, $req ) {
 
-    # .js class request
+    # .js file request
     if ( $req->{path_tail} && $req->{path_tail} =~ /\A(.+)[.]js\z/sm ) {
         my $extjs_class_name = $1;
 
@@ -157,18 +165,13 @@ around run => sub ( $orig, $self, $req ) {
 
             # call ExtJS class generation method
             $self->$method($ext);
-        }
-        else {
 
-            # ExtJS class generation method wasn't found
-            $req->(404)->finish;
+            return;
         }
     }
 
-    # fall back
-    else {
-        $self->$orig($req);
-    }
+    # fall back to the original method
+    $self->$orig($req);
 
     return;
 };
@@ -180,7 +183,7 @@ around run => sub ( $orig, $self, $req ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    1 | 85                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([^A-Za-z] vs. [[:^alpha:]])       |
+## |    1 | 93                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([^A-Za-z] vs. [[:^alpha:]])       |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
